# Alexa-Echo-Hue
Amazon alexa echo hue emulation

## Features
- Emulate a Philips Hue Light Bulb
- Control your devices with Alexa Echo
- Asyncronous processing

## Requirements


## Thanks to:
[falk0069](https://github.com/falk0069/hue-upnp) and [IcynatorHD](https://www.npmjs.com/package/node-red-contrib-local-alexa-devices)
